Reader

Struct Reader 

pub struct Reader<T> { /* private fields */ }
Dropping the Reader isn’t realtime safe, because if dropped after the Writer, it deallocates. Should only get dropped, when closing the real-time thread

Reader will be able to read data even if Writer has been dropped. Obviously that data won’t change anymore When there is no Reader the Writer is able to create a new one. The other way around doesn’t work.

Isn’t Sync as there is no methos that takes &self, so it is useless anyways.

Implementations

Source

impl<T> Reader<T>

pub fn lock(&mut self) -> ReadGuard<'_, T>

this function never blocks. (fetch_update loop doesn’t count)