WriteGuard

Struct WriteGuard 

pub struct WriteGuard<'a, T, O> { /* private fields */ }
Can be used to write to the Data structure.

When this structure exists the Reader already switched to the other value

Dropping this makes all changes available to the Reader.

Implementations

Source

impl<T, O> WriteGuard<'_, T, O>

pub fn swap(self)

Makes the changes available to the reader. Equivalent to std::mem::drop(self)

pub fn read(&self) -> &T

Gets the value currently being written to.

Source

impl<T: Absorb<O>, O: Clone> WriteGuard<'_, T, O>

pub fn apply_op(&mut self, operation: O)

applies operation to the current write Value and stores it to apply to the other later. If there is no reader the operation is applied to both values immediately and not stored.