pub struct Writer<T, O> { /* private fields */ }Expand description
Not realtime safe object which can change the internal T value.
Implementations
Sourceimpl<T, O> Writer<T, O>
impl<T, O> Writer<T, O>
Sourcepub fn build_reader(&mut self) -> Option<Reader<T>>
pub fn build_reader(&mut self) -> Option<Reader<T>>
get a Reader if none exists
Sourceimpl<T: Absorb<O>, O> Writer<T, O>
impl<T: Absorb<O>, O> Writer<T, O>
Sourcepub fn try_lock(&mut self) -> Option<WriteGuard<'_, T, O>>
pub fn try_lock(&mut self) -> Option<WriteGuard<'_, T, O>>
doesn’t block. Returns None if the Reader has a ReadGuard pointing to the old value.
Sourceimpl<T: Sync, O> Writer<T, O>
impl<T: Sync, O> Writer<T, O>
Sourcepub fn read(&self) -> &T
pub fn read(&self) -> &T
The Value returned may be newer than the version the reader is currently seeing.
This value will be written to next.
If this is called after swapping the write_lock this will return an older value.
To get the newest value lock the writer and call Writeguard::read.
Needs T: Sync because maybe this is the value the reader is curently reading