pub struct WriteGuard<'a, T, O> { /* private fields */ }Expand description
Can be used to write to the Data structure.
When this structure exists the Reader already switched to the other value
Dropping this makes all changes available to the Reader.
Implementations
Sourceimpl<T, O> WriteGuard<'_, T, O>
impl<T, O> WriteGuard<'_, T, O>