Struct Writer

pub struct Writer<T, O> { /* private fields */ }
Not realtime safe object which can change the internal T value.

Implementations

Source

impl<T, O> Writer<T, O>

pub fn build_reader(&mut self) -> Option<Reader<T>>

get a Reader if none exists

Source

impl<T: Absorb<O>, O> Writer<T, O>

pub fn try_lock(&mut self) -> Option<WriteGuard<'_, T, O>>

doesn’t block. Returns None if the Reader has a ReadGuard pointing to the old value.

Source

impl<T: Clone, O> Writer<T, O>

pub fn new(value: T) -> Self

Creates a new Writer by cloning the value once to get two values T::clone() shoulnd’t give a different value, as that would make this library pretty useless

Source

impl<T: Sync, O> Writer<T, O>

pub fn read(&self) -> &T

The Value returned may be newer than the version the reader is currently seeing. This value will be written to next. If this is called after swapping the write_lock this will return an older value. To get the newest value lock the writer and call Writeguard::read.

Needs T: Sync because maybe this is the value the reader is curently reading