Struct simple_left_right::Writer

source ·
pub struct Writer<T, O> { /* private fields */ }
Not realtime safe Object which can change the internal T value

Implementations

source

impl<T, O> Writer<T, O>

source

pub fn build_reader(&mut self) -> Option<Reader<T>>

get a Reader if none exists

source

pub fn read(&self) -> &T

The Value returned may be newer than the version the reader is currently seeing. This value will be written to next.

source

impl<T: Absorb<O>, O> Writer<T, O>

source

pub fn lock(&mut self) -> WriteGuard<'_, T, O>

Blocks if the Reader has a ReadGuard pointing to the old value.

Uses a Spinlock because for anything else the OS needs to be involved. Reader can’t talk to the OS.

source

pub fn try_lock(&mut self) -> Option<WriteGuard<'_, T, O>>

doesn’t block. Returns None if the Reader has a ReadGuard pointing to the old value

source

impl<T: Clone, O> Writer<T, O>

source

pub fn new(value: T) -> Self

Creates a new Writer by cloning the value once to get two values