Struct simple_left_right::Writer
source · pub struct Writer<T, O> { /* private fields */ }Expand description
Not realtime safe Object which can change the internal T value
Implementations
sourceimpl<T: Absorb<O>, O> Writer<T, O>
impl<T: Absorb<O>, O> Writer<T, O>
sourcepub fn lock(&mut self) -> WriteGuard<'_, T, O>
pub fn lock(&mut self) -> WriteGuard<'_, T, O>
Blocks if the Reader has a ReadGuard pointing to the old value.
Uses a Spinlock because for anything else the OS needs to be involved. Reader can’t talk to the OS.
sourcepub fn try_lock(&mut self) -> Option<WriteGuard<'_, T, O>>
pub fn try_lock(&mut self) -> Option<WriteGuard<'_, T, O>>
doesn’t block. Returns None if the Reader has a ReadGuard pointing to the old value