pub trait Absorb<O> { // Required method fn absorb(&mut self, operation: O); }
Should be implemented on structs that want to be shared with this library
has to be deterministic. Operations will be applied in the same order to both buffers